//------------------------------------------------------------------------
//
// OpenDCC - OpenDecoder2/OpenDecoder3
//
// Copyright (c) 2007 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      cv_data_signal.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2007-08-03 V0.1 kw start
//            2007-08-18 V0.2 kw default for myADDR hight changed to 0x80
//                               -> this means: unprogrammed
//            
//
//------------------------------------------------------------------------
//
// purpose:   flexible general purpose decoder for dcc
//            This is the cv-structure definition for the project
//            cv_data_xxxxx.c will contain the actual data.
//
//------------------------------------------------------------------------
//
// content:   1. ....
//
//========================================================================
////-----------------------------------------------------------------------------
// data in EEPROM:
// Note: the order of these data corresponds to physical CV-Address
//       CV1 is coded at #00
//       see RP 9.2.2 for more information


//-----------------------------------------------------------------------------
// data in EEPROM:
// Note: the order of these data corresponds to physical CV-Address
//       CV1 is coded at #00
//       see RP 9.2.2 for more information

// Content          Name       CV  -alt  type    comment
   0x01,        //  myAddrL    513   1   M       Decoder Adresse low, 6 bits
   0,           //  auxActiv   514   2  O       Auxiliary activation of outputs: 0=no aux activation
   15,          //  T_on_F1    515   3  O       Time on F1
   15,          //  T_on_F2    516   4  O       Time on F2
   15,          //  T_on_F3    517   5  O       Time on F3
   15,          //  T_on_F4    518   6  O       Time on F4
   0x80,        //  version    519   7  M       Version (8-0)
   0x0D,        //  VID        520   8  M       Vendor ID (0x0D = DIY Decoder)
                //                                        (0x3E = TAMS)
   0x80,        //  myAddrH    521   9  M       Decoder Adresse high (3 bits)
   0,           //  cv522      522  10  -       reserved
   0,           //  cv523      523  11  -       reserved
   0,           //  cv524      524  12  -       reserved
   0,           //  cv525      525  13  -       reserved
   0,           //  cv526      526  14  -       reserved
   0,           //  cv527      527  15  -       reserved
   0,           //  cv528      528  16  -       reserved
   0,           //  cv529      529  17  -       reserved
   0,           //  cv530      530  18  -       reserved
   0,           //  cv531      531  19  -       reserved
   0,           //  cv532      532  20  -       reserved
   0,           //  cv533      533  21  -       reserved
   0,           //  cv534      534  22  -       reserved
   0,           //  cv535      535  23  -       reserved
   0,           //  cv536      536  24  -       reserved
   0,           //  cv537      537  25  -       reserved
   0,           //  cv538      538  26  -       reserved
   0,           //  cv539      539  27  -       reserved
   0,           //  BiDi       540  28  -       Bi-Directional Communication Config - keep at 0
                //  Config     541  29  -       similar to CV#29; for acc. decoders
                     (1<<7)                   // 1 = we are accessory
                   | (0<<6)                   // 0 = we do 9 bit decoder adressing
                   | (0<<5)                   // 0 = we are basic accessory decoder
                   | 0,                       // 4..0: all reserved
   0,           //  cv542      542  30  -       reserved
   0,           //  cv543      543  31  -       reserved
   0,           //  LastState  544  32  -       saved last port state (was reserved)
                //
                // 545-593 - Manufacturer Unique
                //
   32,          //  MODE       545  33  -      global decoder mode
                                               // 00 = turnout decoder with feedback
                                               // 01 = dual servo decoder
                                               // 02 = multiposition servo decoder
                                               // 03 = direct relay control (only OpenDecoder3)
                                               // 04 = Dual Servodecoder and relay control (only OpenDecoder3)
                                               // ...
                                               // 08 = dmx decoder
                                               // 16 = kirmes decoder
                                               // 32 = Signal Decoder (>>>>>>>> HERE  <<<<<<<<<<)
   1,           //  FM         546  34  -      global feedback mode
                                               // 00 = no feedback
                                               // 01 = pos. feedback (ack)
                                               // 02 = neg. feedback (emergency stop)
   0,           //  FBM_F1     547  35  -      feedback mode Func 1
                                               // 00 = command acknowledge
                                               // 01 = turnout feedback with intrinsic endswitches
                                               // 02 = feedback with extra detector
                                               // 03 = feedback with extra detector
   0,           //  FBM_F2     548  36  -      feedback mode Func 2
   0,           //  FBM_F3     549  37  -      feedback mode Func 3
   0,           //  FBM_F4     550  38  -      feedback mode Func 4


    // SIGNAL Specific

   1,           // LightMode;     551  39  -      general behavior
                                                 // 00 = 4 pairs, switched, 8 addresses (traditional)
                                                 //      (duration according to T_on_xx)
                                                 // 01 = 8 addresses, dimmed, static states
                                                 // 02 = up to 16 addresses, dimmed, static states
                                                 // 03...07 = reserved
                                                 // 08 = traffic lights (Ampel) 8 addresses
                                                 // 09 = rail crossing (Andreaskreuz) 8 addresses
                                                 // 10 = Flasher
                                                 // 11...15 reserved
                                                 // 16 = Lichtsule (aus, langsam, schnell)
                                                 // 17 = Lichterkette vorwrts (aus, eine langsam, zwei langsam, drei,  schnell)
                                                 // 18 = Lichterkette rckwrts (aus, eine langsam, zwei langsam, drei,  schnell)
                                                 // 19 = Baustellenblitzer

   1,           // SignalType;     552          
                                                    // 00 = user defined (up to 16 addresses/aspects)
                                                    // 01 = 4 Sig, 2 aspects, individual LED
                                                    // 02 = 2 Sig, 3 aspects, individual LED
                                                    // 03 = 2 Sig, Einfahrsignal + Vorsignal getrennt
                                                    // 04 = 2 Sig, Einfahrsignal + Vorsignal kombiniert
                                                    // 05 = 8 Sig, on/off  (uses 16 aspects)
                                                    // 06 = 4 Sig, kombinatorisch (uses 16 aspects)
                                                    // 07 = 2 Sig, 7 aspects, belgian

    16,         // NoOfAspects;    553              // for user defined pattern

                // bulb behavior    
    5,          // DimmUpSpeed;    554              // increment
    60,         // TargetUp;       555              // Value for ON (range 100 ... 160)
    50,         // TargetUpNight;  556              // Value for ON (range 100 ... 160)
    3,          // DimmDownSpeed;  557              // decrement
    0,          // TargetDown;     558              // Value for OFF (range 100 ... 160)

    20,         // DimmUpDelay;    559           // if a state changes, this setting delays the turn on 
    10,         // BlinkPeriod_2;  560           // half of Period, given in ticks
    
    10,         // Ontime          561
    150,        // IntervalPeriod; 562           // long Pause 
    15,         // StrokePeriod;   563           // short Pause

    0,          //  reserved_564;


    { {0b00000011, 0b00000001, 0b00000000},  // Aspect 00: VALID, PATTERN, BLINK
      {0b00000011, 0b00000010, 0b00000000},  // Aspect 01: VALID, PATTERN, BLINK
      {0b00001100, 0b00000100, 0b00000000},  // Aspect 02: VALID, PATTERN, BLINK
      {0b00001100, 0b00001000, 0b00000000},  // Aspect 03: VALID, PATTERN, BLINK
      {0b00110000, 0b00010000, 0b00000000},  // Aspect 04: VALID, PATTERN, BLINK
      {0b00110000, 0b00100000, 0b00000000},  // Aspect 05: VALID, PATTERN, BLINK
      {0b11000000, 0b01000000, 0b00000000},  // Aspect 06: VALID, PATTERN, BLINK
      {0b11000000, 0b10000000, 0b00000000},  // Aspect 07: VALID, PATTERN, BLINK
      {0b11110000, 0b10100000, 0b11110000},  // Aspect 08: VALID, PATTERN, BLINK // Wechselblink oben
      {0b00000000, 0b01000000, 0b00000000},  // Aspect 09: VALID, PATTERN, BLINK
      {0b00000000, 0b10000000, 0b00000000},  // Aspect 10: VALID, PATTERN, BLINK
      {0b00000000, 0b10100000, 0b11110000},  // Aspect 11: VALID, PATTERN, BLINK
      {0b00000000, 0b01000000, 0b00000000},  // Aspect 12: VALID, PATTERN, BLINK
      {0b00000000, 0b10000000, 0b00000000},  // Aspect 13: VALID, PATTERN, BLINK
      {0b00000000, 0b10100000, 0b11110000},  // Aspect 14: VALID, PATTERN, BLINK
      {0b00000000, 0b01000000, 0b00000000},  // Aspect 15: VALID, PATTERN, BLINK     
    }, 
    0,           // HauptState;    613         // Hauptsignal (or lower ports)
    0,           // VorState;      614         // Vorsignal (or upper ports)   

