//------------------------------------------------------------------------
//
// OpenDCC - OpenDecoder3
//
// Copyright (c) 2007 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      cv_signal.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2007-08-03 V0.1 kw start
//            2007-09-18 V0.2 kw CV554 bis CV559 ergnzt, damit TP File
//                               und OpenDecoder3 konsistent (war vergessen) 
//            2008-05-29 V0.3 kw added variables to save internal states
//
//------------------------------------------------------------------------
//
// purpose:   flexible general purpose decoder for dcc
//            This is the cv-structure definition for the project
//            cv_data_xxxxx.h will contain the actual data.
//
//------------------------------------------------------------------------
//
// content:   1. ....
//
//========================================================================
#ifndef _CV_DEFINE_H_
#define _CV_DEFINE_H_
////-----------------------------------------------------------------------------
// data in EEPROM:
// Note: the order of these data corresponds to physical CV-Address
//       CV1 is coded at #00
//       see RP 9.2.2 for more information


typedef struct
  {
    //            Name              default    CV  -alt  type    comment
    unsigned char myAddrL;     //513   1  M       Decoder Adresse low, 6 bits
    unsigned char auxActiv;    //514   2  O       Auxiliary activation of outputs: 0=no aux activation
    unsigned char T_on_F1;     //515   3  O       Time on F1
    unsigned char T_on_F2;     //516   4  O       Time on F2
    unsigned char T_on_F3;     //517   5  O       Time on F3
    unsigned char T_on_F4;     //518   6  O       Time on F4
    unsigned char version;     //519   7  M       Version
    unsigned char VID    ;     //520   8  M       Vendor ID (0x0D = DIY Decoder, 0x12 = JMRI, 0x3E = TAMS)
    unsigned char myAddrH;     //521   9  M       Decoder Adresse high (3 bits)
    unsigned char cv522  ;     //522  10  -       reserved
    unsigned char cv523    ;   //523  11  -       reserved
    unsigned char cv524    ;   //524  12  -       reserved
    unsigned char cv525    ;   //525  13  -       reserved
    unsigned char cv526    ;   //526  14  -       reserved
    unsigned char cv527    ;   //527  15  -       reserved
    unsigned char cv528    ;   //528  16  -       reserved
    unsigned char cv529    ;   //529  17  -       reserved
    unsigned char cv530    ;   //530  18  -       reserved
    unsigned char cv531    ;   //531  19  -       reserved
    unsigned char cv532    ;   //532  20  -       reserved
    unsigned char cv533    ;   //533  21  -       reserved
    unsigned char cv534    ;   //534  22  -       reserved
    unsigned char cv535    ;   //535  23  -       reserved
    unsigned char cv536    ;   //536  24  -       reserved
    unsigned char cv537    ;   //537  25  -       reserved
    unsigned char cv538    ;   //538  26  -       reserved
    unsigned char cv539    ;   //539  27  -       reserved
    unsigned char BiDi   ;     //540  28  -       Bi-Directional Communication Config - keep at 0
    unsigned char Config ;     //541  29  -       similar to CV#29; for acc. decoders
    unsigned char cv542    ;   //542  30  -       reserved
    unsigned char cv543    ;   //543  31  -       reserved
    unsigned char LastState;   //544  32  -       saved last port state (was reserved)
    //
    // 545-593 - Manufacturer Unique
    //
    unsigned char MODE;        //545  33  -      global decoder mode
                                                                // 00 = turnout decoder with feedback
                                                                // 01 = dual servo decoder
                                                                // 02 = multiposition servo decoder
                                                                // 03 = relais direct
                                                                // 04 = reserved
                                                                // ...
                                                                // 08 = dmx decoder
                                                                // 32 = signal decoder (here)
    unsigned char FM ;         //546  34  -      global feedback mode
                                                                // 00 = no feedback
                                                                // 01 = pos. feedback (ack)
                                                                // 02 = neg. feedback (emergency stop)
    unsigned char FBM_F1;      //547  35  -      feedback mode Func 1
                                                                // 00 = command acknowledge
                                                                // 01 = turnout feedback with intrinsic endswitches
                                                                // 02 = feedback with extra detector
                                                                // 03 = feedback with extra detector
    unsigned char FBM_F2;       //548  36  -      feedback mode Func 2
    unsigned char FBM_F3;       //549  37  -      feedback mode Func 3
    unsigned char FBM_F4;       //550  38  -      feedback mode Func 4

    // SIGNAL Specific

    unsigned char LightMode;    //551  39  -      general behavior
                                                         // 00 = 4 pairs, switched, 8 addresses (traditional)
                                                         //      (duration according to T_on_xx)
                                                         // 01 = 8 addresses, dimmed, static states
                                                         // 02 = 16 addresses, dimmed, static states
                                                         // 03 = userdef states
                                                         // 05...07 = reserved
                                                         // 08 = traffic lights (Ampel) 8 addresses
                                                         // 09 = rail crossing (Andreaskreuz) 8 addresses
                                                         // 10 = Flasher
                                                         // 11...15 reserved
                                                         // 16 = Lichtsule (aus, langsam, schnell)
                                                         // 17 = Lichterkette vorwrts (aus, eine langsam, zwei langsam, drei,  schnell)
                                                         // 18 = Lichterkette rckwrts (aus, eine langsam, zwei langsam, drei,  schnell)
                                                         // 19 = Baustellenblitzer

    unsigned char SignalType;   //552          
                                                    // 00 = user defined (up to 16 addresses/aspects)
                                                    // 01 = 4 Sig, 2 aspects, individual LED
                                                    // 02 = 2 Sig, 3 aspects, individual LED
                                                    // 03 = 2 Sig, Einfahrsignal + Vorsignal getrennt
                                                    // 04 = 2 Sig, Einfahrsignal + Vorsignal kombiniert
                                                    // 05 = 8 Sig, on/off  (uses 16 aspects)
                                                    // 06 = 4 Sig, kombinatorisch (uses 16 aspects)
                                                    // 07 = 2 Sig, 7 aspects, belgian

    unsigned char NoOfAspects;   //553              // for user defined pattern

    // bulb behavior    
    unsigned char DimmUpSpeed;   //554                 // increment
    unsigned char TargetUp;      //555             // Value for ON (range 0 .. 60)
    unsigned char TargetUpNight; //556                 // Value for ON (range 100 ... 160)
    unsigned char DimmDownSpeed; //557                  // decrement
    unsigned char TargetDown;    //558              // Value for OFF (range 100 ... 160)

    unsigned char DimmUpDelay;   //559           // if a state changes, this setting delays the turn on 

    unsigned char BlinkPeriod_2; //560         // half of Period, given in ticks
    
    // running lights
    unsigned char Ontime;        //561         // Leuchtdauer 
    unsigned char IntervalPeriod;//562         // long Pause 
    unsigned char StrokePeriod;  //563         // short Pause

    unsigned char reserved_564;


    struct
    { unsigned char Valid;      // one entry for each aspect, 1 marks the affected outputs
      unsigned char Pattern;    // one entry for each aspect, target pattern for on;
      unsigned char Blink;      // one entry for each aspect, target pattern for blinking
    } UDEF[16];

    // saved states
    unsigned char HauptState;    //613         // Hauptsignal (or lower ports)
    unsigned char VorState;      //614         // Vorsignal (or upper ports) 

 } t_cv_record;


#endif  // _CV_DEFINE_H_
