//------------------------------------------------------------------------
//
// OpenDCC - OpenDecoder2
//
// Copyright (c) 2006 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      hardware.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2006-02-14 V0.1 kw copied from opendecoder.c
//            2007-05-21 V0.2 kw added OpenDecoder3
//
//------------------------------------------------------------------------
//
// purpose:   flexible general purpose decoder for dcc
//            here: hardware definitions
//
//
//------------------------------------------------------------------------
#ifndef _HARDWARE_H_
#define _HARDWARE_H_

#ifndef TARGET_HARDWARE
#warning: SEVERE: no target hardware defined! Code will not work!
#endif


//========================================================================

#if (TARGET_HARDWARE == OPENDECODER2) 
//---------------------------------------------------------------------
// CPU Definitions:
//

#define  PROCESSOR     ATMEGA8515        
// if changed: check timings, timer settings, baudrate

#if (PROCESSOR == ATMEGA8515)
  // atmega8515:   512 Byte SRAM, 512 Byte EEPROM
  #define SRAM_SIZE    512
  #define EEPROM_SIZE  512
  #define EEPROM_BASE  0x810000L
#endif


#ifndef F_CPU
   // prevent compiler error by supplying a default 
   # warning "F_CPU not defined", set default to 8MHz 
   # define F_CPU 8000000UL
   // if changed: check every place where it is used
   // (possible range underflow/overflow in preprocessor!)
#endif


//---------------------------------------------------------------------------
// PORT Definitions:
//
// PORTA:
#define FEEDBACK_PULLUP PORTA
#define FEEDBACK_IN     PINA

// PORTB:
#define OUTPUT_PORT     PORTB    // this is the main output port

// PORTC:
// unused - all ports are routed to vias

// PORTD:
#define RS485_RX        0
#define RS485_TX        1
#define DCCIN           2       // must be located on INT0
#define JUMPER          3       // if Jumper fitted: state is saved in EEPROM
#define PROGTASTER      4
#define SERVO1          5       // output (OC1A)
#define LED             6       // output, 1 turns on LED
#define DCC_ACK         7       // output, sending 1 makes an ACK

#define DCC_PORT        PORTD   // must be defined to have portable code
#define DCC_PORT_IN     PIND    // must be defined to have portable code

#define DCCIN_STATE     (PIND & (1<<DCCIN))

#define PROG_PRESSED    (!(PIND & (1<<PROGTASTER)))
#define JUMPER_FITTED   (!(PIND & (1<<JUMPER)))
#define LED_OFF         PORTD &= ~(1<<LED)
#define LED_ON          PORTD |= (1<<LED)
#define DCC_ACK_OFF     PORTD &= ~(1<<DCC_ACK)
#define DCC_ACK_ON      PORTD |= (1<<DCC_ACK)

// Note LEDs is active high -> state on == pin high!
#define LED_STATE       ((PIND & (1<<LED)))

#define DMX_OUT         1
#define DMX_PORT        PORTD


// PORTE:
#define DMXDIR          0
#define SERVO2          2      // output (OC1B)

#define DMXDIR_SEND     PORTE |= (1<<DMXDIR)
#define DMXDIR_REC      PORTE &= ~(1<<DMXDIR)

// #endif // (TARGET_HARDWARE == OPENDECODER2) 

//========================================================================
//========================================================================

#elif (TARGET_HARDWARE == OPENDECODER3) 
//---------------------------------------------------------------------
// CPU Definitions:
//

#define  PROCESSOR     ATMEGA162        
// if changed: check timings, timer settings, baudrate

#if (PROCESSOR == ATMEGA162)
  // atmega8515:   16k Flash, 1k Byte SRAM, 512 Byte EEPROM
  #define SRAM_SIZE    1024
  #define EEPROM_SIZE  512
  #define EEPROM_BASE  0x810000L
#endif


#ifndef F_CPU
   // prevent compiler error by supplying a default 
   # warning "F_CPU not defined", set default to 8MHz 
   # define F_CPU 8000000UL
   // if changed: check every place where it is used
   // (possible range underflow/overflow in preprocessor!)
#endif

//---------------------------------------------------------------------------
// PORT Definitions:
//
// PORTA:
//#define FEEDBACK_PULLUP PORTA
//#define FEEDBACK_IN     PINA

// PORTB:
#define LED             0       // output, 1 turns on LED
#define DMXDIR          1       // output, 1 = send
#define RS485_RX        2
#define RS485_TX        3


#define LED_OFF         PORTB &= ~(1<<LED)      // use only these macros to access LED
#define LED_ON          PORTB |= (1<<LED)
#define LED_STATE       ((PINB & (1<<LED)))

#define DMXDIR_SEND     PORTB |= (1<<DMXDIR)
#define DMXDIR_REC      PORTB &= ~(1<<DMXDIR)

#define DMX_OUT         3
#define DMX_PORT        PORTB


// PORTC:
#define RELAIS1         0       // output, 1 turn on relais
#define RELAIS2         1       // output, 1 turn on relais
#define RELAIS3         2       // output, 1 turn on relais
#define RELAIS4         3       // output, 1 turn on relais
#define KEY1            4       // input, requires pull up
#define KEY2            5       // input, requires pull up
#define KEY3            6       // input, requires pull up
#define KEY4            7       // input, requires pull up

#define OUTPUT_PORT     PORTC    // this is the main output port
#define KEY_PORT        PINC     // This is the port where we read bits
#define KEY_MASK        0xF0     // the keyboard task runs only on
                                 // those ports defined in the mask
                                 // Ports not in the mask are ignored
#define KEY_OFFSET      -4       // shift keystroke result with this number



// PORTD:
#define LN_IN           0
#define RAILCOM         1       // output (tx0)
#define DCCIN           2       // must be located on INT0
#define JUMPER2         3       // if Jumper fitted: state is saved in EEPROM
#define PROGTASTER      4
#define SERVO1          5       // output (OC1A)
#define RAILCOM_ON      6       // output, 1 turns on LED
#define DCC_ACK         7       // output, sending 1 makes an ACK

#define DCC_PORT        PORTD   // must be defined to have portable code
#define DCC_PORT_IN     PIND    // must be defined to have portable code

#define DCCIN_STATE     (PIND & (1<<DCCIN))

#define PROG_PRESSED    (!(PIND & (1<<PROGTASTER)))
#define JUMPER2_FITTED  (!(PIND & (1<<JUMPER2)))
#define DCC_ACK_OFF     PORTD &= ~(1<<DCC_ACK)
#define DCC_ACK_ON      PORTD |= (1<<DCC_ACK)


// PORTE:
#define RESERV_E0       0       // input, pullup, external resistor
#define JUMPER1         1       // 
#define SERVO2          2       // output (OC1B)
#define JUMPER1_FITTED  (!(PINE & (1<<JUMPER1)))


//----------------------------------------------------------------------------
//
// add Your Target Hardware here!
//
#else
   #warning: SEVERE: unknown target hardware defined! Code will not work!
#endif // TARGET_HARDWARE

#endif // _HARDWARE_
